@@ -163,18 +163,21 @@ describe 'Jekyll::AsciiDoc' do
   end
 
   describe 'imagesdir relative to root' do
-    use_fixture :imagesdir_relative_to_root
+    [nil, :with_baseurl].each do |config_path|
+      describe config_path do
+        use_fixture :imagesdir_relative_to_root, config_path
 
-    before :each do
-      site.object_id
-    end
+        before :each do
+          site.object_id
+        end
 
-    it 'should set imagesoutdir if imagesdir is relative to root' do
-      (expect (asciidoctor_config = site.config['asciidoctor'])).to be_a ::Hash
-      (expect (attrs = asciidoctor_config[:attributes])).to be_a ::Hash
-      (expect attrs['imagesdir']).to eql '/images@'
-      imagesoutdir_expected = ::File.join site.dest, (attrs['imagesdir'].chomp '@')
-      (expect attrs['imagesoutdir']).to eql imagesoutdir_expected
+        it 'should set imagesoutdir if imagesdir is relative to root' do
+          (expect (asciidoctor_config = site.config['asciidoctor'])).to be_a ::Hash
+          (expect (attrs = asciidoctor_config[:attributes])).to be_a ::Hash
+          (expect attrs['imagesdir']).to eql (config_path == :with_baseurl ? '/projectname' : '') + '/images@'
+          (expect attrs['imagesoutdir']).to eql (File.join site.dest, '/images')
+        end
+      end
     end
   end
 
@@ -910,6 +913,7 @@ describe 'Jekyll::AsciiDoc' do
       (expect ::File).to exist file
       contents = ::File.read file
       (expect contents).to include '<div class="excerpt">This is the <em>excerpt</em> of this post.</div>'
+      (expect contents).to include '<div class="synopsis">This is the <em>synopsis</em> of this post.</div>'
     end
 
     it 'should convert excerpt from AsciiDoc using page-specific doctype' do
@@ -1083,6 +1087,7 @@ describe 'Jekyll::AsciiDoc' do
       out_file = output_file 'about/index.html'
       (expect ::File).to exist out_file
       contents = ::File.read out_file
+      (expect contents).to include '<strong>Who</strong> we are.'
       (expect contents).to include 'Doc Writer'
       (expect contents).to include %(docfile=#{src_file})
       (expect contents).to include %(docdir=#{::File.dirname src_file})
@@ -1106,14 +1111,14 @@ describe 'Jekyll::AsciiDoc' do
       (::Jekyll.configuration fixture_site_params name).merge('source' => (::File.join (source_dir name), 'source'))
     end
 
-    before :each do
-      @old_pwd = ::Dir.pwd
-      ::Dir.chdir source_dir name
-      site.process
+    let :new_pwd do
+      source_dir name
     end
 
-    after :each do
-      ::Dir.chdir @old_pwd
+    before :each do
+      ::Dir.chdir source_dir name do
+        site.process
+      end
     end
 
     it 'should not set base_dir if base_dir config key has no value' do
